<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="59"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy name</source>
        <translation>Zkopírovat název</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="68"/>
        <source>Copy ID</source>
        <translation>Zkopírovat identifikátor</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="79"/>
        <source>Pause</source>
        <translation type="unfinished">Pozastavit</translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="75"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="81"/>
        <source>Copy label/ID</source>
        <translation>Zkopírovat jmenovku/identifikátor</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="84"/>
        <source>Copy path</source>
        <translation>Zkopírovat popis umístění</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="89"/>
        <source>Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="94"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="99"/>
        <source>Pause</source>
        <translation type="unfinished">Pozastavit</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="103"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation>Zkopírovat jmenovku/identifikátor</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation>Znovu vše proskenovat</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation>Zobrazit vnitřní chyby</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation>O Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="214"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="234"/>
        <source>Launcher error</source>
        <translation>Chyba spouštěče</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="250"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation>Oznámení ze Syncthing – kliknutím zahodíte</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="280"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation>Syncthing zařízení se chce připojit – klikněte pro webové rozhraní</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="296"/>
        <source>New Syncthing directory - click for web UI</source>
        <translation>Nový Syncthing adresář – klikněte pro webové rozhraní</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="175"/>
        <source>Disconnected from Syncthing</source>
        <translation>Odpojeno od Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation>Otevřít Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation>Záznam událostí</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation>Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="97"/>
        <location filename="../gui/traywidget.cpp" line="275"/>
        <source>About</source>
        <translation>O Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="398"/>
        <source>Connect</source>
        <translation>Připojit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="71"/>
        <location filename="../gui/traywidget.cpp" line="763"/>
        <location filename="../gui/traywidget.cpp" line="805"/>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="110"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="123"/>
        <source>Open Syncthing</source>
        <translation>Otevřít Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="283"/>
        <source>In</source>
        <translation>Přích.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="290"/>
        <source>Incoming traffic</source>
        <translation>Příchozí provoz</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="222"/>
        <location filename="../gui/traywidget.ui" line="242"/>
        <location filename="../gui/traywidget.ui" line="293"/>
        <location filename="../gui/traywidget.ui" line="313"/>
        <source>unknown</source>
        <translation>neznámé</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="212"/>
        <source>Global</source>
        <translation>Globální</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="219"/>
        <source>Global overall statistics</source>
        <translation>Globální celkové statistiky</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="229"/>
        <source>Local</source>
        <translation>Místní</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="239"/>
        <source>Local overall statistics</source>
        <translation>Místní celkové statistiky</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="300"/>
        <source>Out</source>
        <translation>odchoz.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="310"/>
        <source>Outgoing traffic</source>
        <translation>Odchozí provoz</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="350"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation>Kliknutím na &lt;i&gt;nové &lt;/i&gt; oznámení&lt;br&gt;
(pro &lt;i&gt;alle&lt;/i&gt; oznámení, nahlédněte do záznamu událostí)</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="354"/>
        <location filename="../gui/traywidget.cpp" line="154"/>
        <location filename="../gui/traywidget.cpp" line="318"/>
        <source>New notifications</source>
        <translation>Nová oznámení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="384"/>
        <source>Directories</source>
        <translation>Adresáře</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="416"/>
        <source>Devices</source>
        <translation>Zařízení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="448"/>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="476"/>
        <source>Recent changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="512"/>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="522"/>
        <source>Dismiss</source>
        <translation>Zahodit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="126"/>
        <source>View own device ID</source>
        <translation>Zobrazit identifikátor místního zařízení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="131"/>
        <source>Restart Syncthing</source>
        <translation>Restartovat Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="136"/>
        <source>Show Syncthing log</source>
        <translation>Zobrazit záznam událostí v Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="141"/>
        <source>Rescan all directories</source>
        <translation>Znovu proskenovat všechny složky</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="148"/>
        <source>Connection</source>
        <translation>Spojení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="170"/>
        <source>Show internal errors</source>
        <translation>Zobrazit vnitřní chyby</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="185"/>
        <source>Quit Syncthing Tray</source>
        <translation>Ukončit Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="373"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation>Opravdu chcete Syncthing restartovat?</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="399"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation>Nepřipojeno k Syncthing, klikněte pro připojení se</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="411"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="412"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation>Syncthing je spuštěné, kliknutím pozastavíte veškerá zařízení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="417"/>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="418"/>
        <source>At least one device is paused, click to resume</source>
        <translation>Přinejmenším jedno zařízení je pozastaveno, kliknutím pokračujte</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="537"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation>Zadané nastavení spojení &lt;em&gt;%1&lt;/em&gt; není definováno a proto je ignorováno.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="567"/>
        <source>The directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Adresář &lt;i&gt;%1&lt;/i&gt; neexistuje místně.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="578"/>
        <source>The containing directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Obsažený adresář &lt;i&gt;%1&lt;/i&gt; neexistuje místně.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="621"/>
        <source>Copy path</source>
        <translation type="unfinished">Zkopírovat popis umístění</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="625"/>
        <source>Copy device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="628"/>
        <source>Copy directory ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="759"/>
        <location filename="../gui/traywidget.cpp" line="799"/>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="760"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation>Zastavit instanci Syncthing spuštěnou prostřednictvím ikony v oznamovací oblasti</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="764"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation>Spustit Syncthing s vestavěným spouštěčem nastaveným v nastaveních</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="59"/>
        <source>Unable to </source>
        <translation>Nedaří se </translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="100"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation>Oznamovací oblast systémového panelu je (pro tuto chvíli) nedostupná. Je možné otevřít nabídku oznamovací oblasti jako běžné okno pomocí příznaku „--windowed“. Dále je možné spustit s volbou „--wait“ a čekat na to, až bude oznamovací oblast k dispozici (namísto zobrazení této zprávy).</translation>
    </message>
    <message>
        <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
        <translation type="vanished">Je třeba nastavit jako se připojit k Syncthing ze Syncthing Tray.</translation>
    </message>
    <message>
        <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="vanished">Poznamenejme, že dialog nastavení umožňuje importovat URL adresu, přihlašovací údaje a klíč k API z místního nastavení Syncthing.</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="127"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation>Knihovny Qt byly sestaveny bez podpory pro ikonu v oznamovací oblasti. Měli byste otevřít nabídku pro oznamovací oblast jako běžné okno pomocí příznaku -w.</translation>
    </message>
</context>
</TS>
